@@ -4,14 +4,26 @@
 from .between import between
 from .btc_address import btc_address
 from .card import amex, card_number, diners, discover, jcb, mastercard, unionpay, visa
-from .country_code import country_code
+from .country import calling_code, country_code, currency
 from .cron import cron
 from .domain import domain
 from .email import email
 from .encoding import base58, base64
+from .finance import cusip, isin, sedol
 from .hashes import md5, sha1, sha224, sha256, sha512
 from .hostname import hostname
-from .i18n import es_cif, es_doi, es_nie, es_nif, fi_business_id, fi_ssn, fr_department, fr_ssn
+from .i18n import (
+    es_cif,
+    es_doi,
+    es_nie,
+    es_nif,
+    fi_business_id,
+    fi_ssn,
+    fr_department,
+    fr_ssn,
+    ind_aadhar,
+    ind_pan,
+)
 from .iban import iban
 from .ip_address import ipv4, ipv6
 from .length import length
@@ -37,8 +49,10 @@ __all__ = (
     "mastercard",
     "visa",
     "unionpay",
-    # ...
+    # country
+    "calling_code",
     "country_code",
+    "currency",
     # ...
     "cron",
     # ...
@@ -48,6 +62,10 @@ __all__ = (
     # encodings
     "base58",
     "base64",
+    # finance
+    "cusip",
+    "isin",
+    "sedol",
     # hashes
     "md5",
     "sha1",
@@ -65,6 +83,8 @@ __all__ = (
     "fi_ssn",
     "fr_department",
     "fr_ssn",
+    "ind_aadhar",
+    "ind_pan",
     # ...
     "iban",
     # ip_addresses
@@ -85,4 +105,4 @@ __all__ = (
     "validator",
 )
 
-__version__ = "0.27.0"
+__version__ = "0.28.0"
