@@ -81,6 +81,7 @@ def _validate_netloc(
     skip_ipv4_addr: bool,
     may_have_port: bool,
     simple_host: bool,
+    consider_tld: bool,
     private: Optional[bool],
     rfc_1034: bool,
     rfc_2782: bool,
@@ -99,6 +100,7 @@ def _validate_netloc(
             skip_ipv4_addr=skip_ipv4_addr,
             may_have_port=may_have_port,
             maybe_simple=simple_host,
+            consider_tld=consider_tld,
             private=private,
             rfc_1034=rfc_1034,
             rfc_2782=rfc_2782,
@@ -114,6 +116,7 @@ def _validate_netloc(
         skip_ipv4_addr=skip_ipv4_addr,
         may_have_port=may_have_port,
         maybe_simple=simple_host,
+        consider_tld=consider_tld,
         private=private,
         rfc_1034=rfc_1034,
         rfc_2782=rfc_2782,
@@ -155,6 +158,7 @@ def url(
     may_have_port: bool = True,
     simple_host: bool = False,
     strict_query: bool = True,
+    consider_tld: bool = False,
     private: Optional[bool] = None,  # only for ip-addresses
     rfc_1034: bool = False,
     rfc_2782: bool = False,
@@ -196,6 +200,8 @@ def url(
             URL string maybe only hyphens and alpha-numerals.
         strict_query:
             Fail validation on query string parsing error.
+        consider_tld:
+            Restrict domain to TLDs allowed by IANA.
         private:
             Embedded IP address is public if `False`, private/local if `True`.
         rfc_1034:
@@ -227,6 +233,7 @@ def url(
             skip_ipv4_addr,
             may_have_port,
             simple_host,
+            consider_tld,
             private,
             rfc_1034,
             rfc_2782,
